##  Modifying Subscription Details
To edit a subscription, do the following:
  1. In the fact sheet, navigate to the Subscriptions tab.
  2. Click the edit icon (depicted by a pencil) next to the subscriber you want to modify. This action opens an overlay, allowing you to modify the subscription type or roles.
  3. After making the changes, click Save.
